import React from "react";
import cockpit from "cockpit";
import { Alert, Button } from "@patternfly/react-core";
import { PictoryService } from "./PictoryService.js";
import { OutlinedWindowRestoreIcon } from "@patternfly/react-icons";

const _ = cockpit.gettext;
export class PictoryLink extends React.Component {
    constructor () {
        super();
        this.service = new PictoryService();
        this.state = {
            isLoading: false,
            hasError: false
        };
    }

    constructURL (token) {
        return `https://${window.location.hostname}:41443/pictory/php/sso_login.php?sso_token=${token}`;
    }

    async handlePiCtoryButtonClick () {
        this.setState({ isLoading: true });
        try {
            const token = await this.service.createSsoToken();
            const url = this.constructURL(token);
            window.open(url, "_blank");
        } catch (e) {
            this.setState({ hasError: true });
            console.error("Error while creating SSO token", e);
        } finally {
            this.setState({ isLoading: false });
        }
    }

    render () {
        if (this.state.hasError) {
            return (
                <Alert
                    variant='error' isInline
                    title={_("An issue occurred while generating your login token for PiCtory.")}
                />
            );
        }
        return (
            <>
                <Button
                    isBlock
                    variant='primary'
                    size='lg'
                    icon={<OutlinedWindowRestoreIcon />}
                    isLoading={this.state.isLoading}
                    isDisabled={this.service.noPictoryAvailable}
                    onClick={() => this.handlePiCtoryButtonClick()}
                >
                    PiCtory
                </Button>
                {this.service.noPictoryAvailable && (
                    <Alert
                        variant='info' isInline isPlain
                        title={_("Launching PiCtory from a device other than your current cockpit host is not currently supported.")}
                    />
                )}
            </>
        );
    }
}
